@@ -10,7 +10,7 @@ var indexSectionsWithContent =
   7: "acdefiprtuvw",
   8: "abcdefghiklmnoprstuvwy",
   9: "do",
-  10: "cpqst",
+  10: "cefpqst",
   11: "3abcdfghilmnopqrstuvw"
 };
 
